# GitStat-统计代码提交次数的小工具

- 安装方法 `pip install gitstat`

- 使用方法 `gitstat [options...]`

- 说明

默认统计运行时刻到一年前时段内当前目录下所有Git仓库中的Git默认用户的提交次数和代码行数.
可以使用`-s` `-e`指定统计的开始时间和结束时间,使用`-a`指定统计的用户名,`-t`指定扫描根路径.

- 帮助 `gitstat --help`


